@@ -46,6 +46,9 @@
 #include <linux/pci.h>
 
 #if defined(RHEL_MAJOR) && defined(RHEL_MINOR)
+# if RHEL_MAJOR == 8 && RHEL_MINOR >= 2
+#  define RHEL_82
+# endif
 # if RHEL_MAJOR == 8 && RHEL_MINOR >= 1
 #  define RHEL_81
 # endif
